@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1516.2.2 2023/10/02 21:46:36 sthen Exp $
+# $OpenBSD: Quirks.pm,v 1.1555 2023/09/30 13:25:43 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -775,6 +775,17 @@ my $stem_extensions = {
 	'py3-wxPython-webkit' => 'py3-wxPython-webview',
 	'wxWidgets-webkit' => 'wxWidgets-webview',
 	'ring' => 'rust-ring',
+# 7.4
+	'aarch64-none-elf-gcc-linaro' => 'aarch64-none-elf-gcc',
+	'arm-none-eabi-gcc-linaro' => 'arm-none-eabi-gcc',
+	'py3-sabyenc' => 'py3-sabctools',
+	'py-libdnet' => 'py3-libdnet',
+	'scons-py2' => 'scons',
+	'qxlsx' => 'qt5-qxlsx',
+	'py-altgraph' => 'py3-altgraph',
+	'pymodbus' => 'py3-pymodbus',
+	'py-yaml' => 'py3-yaml',
+	'kalendar' => 'merkuro',
 };
 
 my $obsolete_reason = {};
@@ -1355,7 +1366,7 @@ setup_obsolete_reason(
 	0 => 'lazarus',
 	13 => 'exaile',
 	3 => 'instead-launcher',
-	3 => qr{^(ruby(19|2[0-7])-|^ruby-[^0-9])},
+	3 => qr{^(ruby(19|2[0-7])-|^j?ruby-[^0-9])},
 # 6.9
 	3 => 'py-notify',
 	3 => 'glimpse',
@@ -1814,6 +1825,35 @@ setup_obsolete_reason(
 	6 => 'elasticsearch',
 	3 => 'ogmrip',
 	3 => 'shrip',
+# 7.4
+	53 => 'compton',
+	54 => 'depotdownloader',
+	55 => 'residualvm',
+	5 => 'p5-Test-Group',
+	9 => 'thedarkmod',
+	3 => 'qtav',
+	3 => 'ruby31-mysql',
+	3 => 'ruby32-mysql',
+	3 => 'libquicktime',
+	3 => 'gnome-twitch',
+	5 => 'sfio',
+	3 => 'parrot',
+	3 => 'kfloppy',
+	3 => 'py3-hypatia',
+	1 => 'reprepro',
+	5 => 'ocaml-pcre',
+	1 => 'breeze-grub',
+	3 => 'mldonkey',
+	3 => 'monotone',
+	3 => 'botan',
+	3 => 'bg5ps',
+	9 => 'haxe',
+	1 => 'libxcvt',
+	1 => 'ocaml-camlp4',
+	1 => 'ocaml-camlp5',
+	3 => 'freetype',
+	3 => 'freetype-doc',
+	6 => 'ipcheck',
 );
 
 # though it's not yet used, these should be pkgnames, so that eventually
@@ -1831,6 +1871,7 @@ my $obsolete_suggestion = {
 	'lives' => [qw(kdenlive shotcut)],
 	'pdfshuffler' => 'pdfarranger',
 	'gotweb' => 'gotwebd',
+	'compton' => 'picom',
 };
 
 # reasons for obsolete packages
@@ -1881,6 +1922,9 @@ my $obsolete_message = {
 	50 => "abandoned ten years ago, broken by default due to missing runtime dependencies, use security/sslscan",
 	51 => "dead upstream, consider using socat or SSH",
 	52 => "unmaintained since import, already on LibreSSL life support for too long",
+	53 => "upstream is dead, consider migrating to picom",
+	54 => "dependencies for recent versions can't be met (dotnet), consider switching to steamctl",
+	55 => "residualvm is dead upstream and has been merged into scummvm",
 };
 
 # ->is_base_system($handle, $state):
@@ -2029,6 +2073,7 @@ my $cve = {
 	'lang/ruby/2.5,-main' => 'ruby->2.5,<2.5.5',
 	'lang/ruby/2.6,-main' => 'ruby->2.6,<2.6.2',
 	'mail/dovecot,-server' => 'dovecot-<2.3.10.1',
+	'mail/exim,-main' => 'exim-<4.97', # ...at least
 	'mail/isync' => 'isync-<1.4.4',
 	'mail/mailman' => 'mailman-<2.1.30',
 	'mail/p5-Mail-SpamAssassin' => 'p5-Mail-SpamAssassin-<3.4.4',
@@ -2111,9 +2156,9 @@ my $cve = {
 	'www/tomcat/v8' => 'tomcat-<8.5.55',
 	'www/tomcat/v9' => 'tomcat-<9.0.35',
 	'www/webkitgtk4' => 'webkitgtk4-<2.20.5',
+	'www/yt-dlp' => 'yt-dlp-<2023.07.06',
 	'x11/gnome/gdm' => 'gdm-<3.28.3',
 	'x11/rdesktop' => 'rdesktop-<1.8.4',
-	'mail/exim,-main' => 'exim-<4.97',
 };
 # please maintain sort order in above $cve list, future updates need to
 # replace existing entries
